@@ -1,9 +1,12 @@
 from __future__ import print_function
 import sys, os
 import pprint
+print("sys.path", sys.path)
+import PIL
+print("x")
 import PIL.Image
 
-PATH="/Library/Application Support/Carbonite/CarboniteAlerts.app/Contents/Resources/background_left_illustration.jpg"
+PATH="/System/Library//Automator/Crop Images.action/Contents/Resources/shark-tall-no-scale.jpg"
 
 print("globals() is %r" % id(globals()))
 def somefunc():
@@ -24,4 +27,4 @@ if __name__ == '__main__':
     img = PIL.Image.open(PATH)
     print(type(img))
     print(img.size)
-    pprint.pprint(list(sorted(sys.modules.keys())))
+    print(PIL.Image.__file__)
