@@ -475,9 +475,10 @@ class py2app(Command):
         self.xref = False
         self.graph = False
         self.no_zip = 0
-        self.optimize = 0
-        if hasattr(sys, 'flags'):
-            self.optimize = sys.flags.optimize
+        self.optimize = None
+        #self.optimize = 0
+        #if hasattr(sys, 'flags'):
+            #self.optimize = sys.flags.optimize
         self.arch = None
         self.strip = True
         self.no_strip = False
@@ -557,6 +558,11 @@ class py2app(Command):
             self._python_app = os.path.join(
                 sys.prefix, 'Resources', 'Python.app')
 
+        if self.optimize is None:
+            self.optimize = 0
+            if hasattr(sys, 'flags'):
+                self.optimize = sys.flags.optimize
+
         if not self.strip:
             self.no_strip = True
         elif self.no_strip:
@@ -610,8 +616,15 @@ class py2app(Command):
         if not self.plist:
             self.plist = {}
         if isinstance(self.plist, basestring):
-            self.plist = plistlib.Plist.fromFile(self.plist)
-        if isinstance(self.plist, plistlib.Dict):
+
+            if hasattr(plistlib, 'load'):
+                with open(self.plist, 'rb') as fp:
+                    self.plist = plistlib.load(fp)
+            else:
+                # 2.7
+                self.plist = plistlib.Plist.fromFile(self.plist)
+        if hasattr(plistlib, 'Dict') and isinstance(self.plist, plistlib.Dict):
+            # 2.7
             self.plist = dict(self.plist.__dict__)
         else:
             self.plist = dict(self.plist)
@@ -997,7 +1010,7 @@ class py2app(Command):
                     continue
                 # we can pull this off so long as we stop the iter
                 del rdict[name]
-                print('*** using recipe: %s ***' % (name,))
+                print('*** using recipe: %s ***' % (name,), rval)
 
                 if 'expected_missing_imports' in rval:
                     self.expected_missing_imports |= rval.get(
@@ -1807,7 +1820,34 @@ class py2app(Command):
             # bootstrap
             prescripts.append('import_encodings')
 
-        if os.path.exists(os.path.join(sys.prefix, ".Python")):
+        if os.path.exists(os.path.join(sys.prefix, "pyvenv.cfg")):
+            # We're in a venv, which means sys.path
+            # will be broken in alias builds unless we fix
+            # it.
+            real_prefix = None
+            global_site_packages = False
+            with open(os.path.join(sys.prefix, "pyvenv.cfg")) as fp:
+
+                for ln in fp:
+                    if ln.startswith('home = '):
+                        _, home_path = ln.split('=', 1)
+                        real_prefix = os.path.dirname(home_path.strip())
+
+                    elif ln.startswith('include-system-site-packages = '):
+                        _, global_site_packages = ln.split('=', 1)
+                        global_site_packages = (global_site_packages == 'true')
+
+            if real_prefix is None:
+                raise DistutilsPlatformError(
+                    'Pyvenv detected, cannot determine base prefix')
+
+            if self.site_packages or self.alias:
+                print("Add paths for VENV", real_prefix, global_site_packages)
+                prescripts.append('virtualenv_site_packages')
+                prescripts.append(StringIO('_site_packages(%r, %r, %d)' % (
+                    sys.prefix, real_prefix, global_site_packages)))
+
+        elif os.path.exists(os.path.join(sys.prefix, ".Python")):
             # We're in a virtualenv, which means sys.path
             # will be broken in alias builds unless we fix
             # it.
@@ -2072,7 +2112,7 @@ class py2app(Command):
             elif fn.endswith('.pyw'):
                 fn = fn[:-4]
 
-            src_fn = script_executable(arch=self.arch, secondary=True)
+            src_fn = script_executable(arch=self.arch, secondary=False)
             tgt_fn = os.path.join(
                 self.appdir, 'Contents', 'MacOS', os.path.basename(fn))
             mergecopy(src_fn, tgt_fn)
