@@ -1,3 +1,4 @@
+from . import botocore  # noqa: F401
 from . import PIL  # noqa: F401
 from . import ctypes  # noqa: F401
 from . import docutils  # noqa: F401
@@ -18,7 +19,9 @@ from . import pyzmq  # noqa: F401
 from . import qt5  # noqa: F401
 from . import re  # noqa: F401
 from . import scipy  # noqa: F401
+from . import shiboken2  # noqa: F401
 from . import sip  # noqa: F401
+from . import six  # noqa: F401
 from . import subprocess  # noqa: F401
 from . import sysconfig_module  # noqa: F401
 from . import tkinter  # noqa: F401
