@@ -1,11 +1,12 @@
 #
 # LXML uses imports from C code (or actually Cython code)
-# and those cannot be detected by modulegraph. 
+# and those cannot be detected by modulegraph.
 # The check function adds the hidden imports to the graph
 #
 # The dependency list was extracted from lxml 3.0.2
 import sys
 
+
 def check(cmd, mf):
     m = mf.findNode('lxml.etree')
     if m is not None and m.filename is not None:
@@ -26,5 +27,12 @@ def check(cmd, mf):
         else:
             mf.import_hook('copyreg', m)
 
-    return {}
+    m = mf.findNode('lxml.isoschematron')
+    if m is not None and m.filename is not None:
+        # Not zip-safe (see issue 118)
+        return dict(packages=['lxml'])
 
+    if mf.findNode('lxml') is None:
+        return None
+
+    return {}
