@@ -12,6 +12,11 @@ import os
 import signal
 import py2app
 import hashlib
+if __name__ == "__main__":
+    from tools import kill_child_processes
+else:
+    from .tools import kill_child_processes
+
 
 DIR_NAME=os.path.dirname(os.path.abspath(__file__))
 
@@ -26,8 +31,11 @@ class TestBasicAppWithExtension (unittest.TestCase):
     # a base-class.
     @classmethod
     def setUpClass(cls):
+        kill_child_processes()
+
         env=os.environ.copy()
         pp = os.path.dirname(os.path.dirname(py2app.__file__))
+        env['TMPDIR'] = os.getcwd()
         if 'PYTHONPATH' in env:
             env['PYTHONPATH'] = pp + ':' + env['PYTHONPATH']
         else:
@@ -43,7 +51,7 @@ class TestBasicAppWithExtension (unittest.TestCase):
                 cwd = cls.app_dir,
             stdout=subprocess.PIPE,
             stderr=subprocess.STDOUT,
-            close_fds=True,
+            close_fds=False,
             env=env
             )
         lines = p.communicate()[0]
@@ -57,7 +65,7 @@ class TestBasicAppWithExtension (unittest.TestCase):
             cwd = cls.app_dir,
             stdout=subprocess.PIPE,
             stderr=subprocess.STDOUT,
-            close_fds=True,
+            close_fds=False,
             env=env
             )
         lines = p.communicate()[0]
@@ -80,6 +88,12 @@ class TestBasicAppWithExtension (unittest.TestCase):
             if fn.endswith('.so'):
                 os.unlink(os.path.join(cls.app_dir, fn))
 
+        time.sleep(2)
+
+    def tearDown(self):
+        kill_child_processes()
+        time.sleep(1)
+
     def start_app(self):
         # Start the test app, return a subprocess object where
         # stdin and stdout are connected to pipes.
@@ -90,7 +104,7 @@ class TestBasicAppWithExtension (unittest.TestCase):
         p = subprocess.Popen([path],
                 stdin=subprocess.PIPE,
                 stdout=subprocess.PIPE,
-                close_fds=True,
+                close_fds=False,
                 )
                 #stderr=subprocess.STDOUT)
         return p
